bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.__init__
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.__init__